﻿using System;
using System.Collections.Generic;
using System.Linq;
using CoreGraphics;
using Foundation;
using Syncfusion.SfChart.iOS;
using Syncfusion.SfChart.XForms;
using Syncfusion.SfChart.XForms.iOS.Renderers;
using UIKit;
using Xamarin.Forms;

namespace SimpleSample.iOS
{
    // The UIApplicationDelegate for the application. This class is responsible for launching the 
    // User Interface of the application, as well as listening (and optionally responding) to 
    // application events from iOS.
    [Register("AppDelegate")]
    public partial class AppDelegate : global::Xamarin.Forms.Platform.iOS.FormsApplicationDelegate
    {
        //
        // This method is invoked when the application has loaded and is ready to run. In this 
        // method you should instantiate the window, load the UI into it and then make the window
        // visible.
        //
        // You have 17 seconds to return from this method, or iOS will terminate your application.
        //
        public override bool FinishedLaunching(UIApplication app, NSDictionary options)
        {
            new SfChartRenderer();
            global::Xamarin.Forms.Forms.Init();
            LoadApplication(new App());

            Xamarin.Forms.Forms.ViewInitialized += (object sender, ViewInitializedEventArgs e) =>
            {
                if (e.View is SfChart)
                {
                    SFChart nativeView = e.NativeView as SFChart;

                    nativeView.AddGestureRecognizer(new CustomGesture(e.View as CustomChart));
                }
            };

            return base.FinishedLaunching(app, options);
        }
    }

    public class CustomGesture : UIPinchGestureRecognizer
    {
        private CustomChart Chart;

        public CustomGesture(CustomChart chart)
        {
            Chart = chart;
        }
        public override void TouchesBegan(NSSet touches, UIEvent evt)
        {
            base.TouchesBegan(touches, evt);

            if (touches.Count == 2)
            {
                NSObject[] sortedTouches = touches.ToArray();

                UITouch touch1 = sortedTouches[0] as UITouch;

                UITouch touch2 = sortedTouches[1] as UITouch;

                CGPoint touch1Point = touch1.LocationInView(View);

                CGPoint touch2Point = touch2.LocationInView(View);

                Chart.Start(touch1Point.X, touch1Point.Y, touch2Point.X, touch2Point.Y);
            }
        }

        public override void TouchesEnded(NSSet touches, UIEvent evt)
        {
            base.TouchesEnded(touches, evt);

            if (touches.Count == 2)
            {
                NSObject[] sortedTouches = touches.ToArray();

                UITouch touch1 = sortedTouches[0] as UITouch;

                UITouch touch2 = sortedTouches[1] as UITouch;

                CGPoint touch1Point = touch1.LocationInView(View);

                CGPoint touch2Point = touch2.LocationInView(View);


                Chart.End(touch1Point.X, touch1Point.Y, touch2Point.X, touch2Point.Y);

            }
        }
    }
}
